#  Copyright (C) 2024
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Mikhail Mamrov <m.mamrov@abm-jsc.ru>
#
from detector_connector import DetectorHttpConnector

from pollution_detector_connector.pollution_settings import PollutionSettings


class PollutionDetectorHttpConnector(DetectorHttpConnector):
    Context = DetectorHttpConnector.Context
    Config = DetectorHttpConnector.Config

    def __init__(self, config: Config, context: Context) -> None:
        super().__init__(config=config, context=context, detector_settings_type=PollutionSettings)
